# Ext: sg_jobs 

<img src="https://www.sgalinski.de/typo3conf/ext/project_theme/Resources/Public/Images/logo.svg" />

License: [GNU GPL, Version 2](https://www.gnu.org/licenses/gpl-2.0.html)

Repository: https://gitlab.sgalinski.de/typo3/sg_jobs

Please report bugs here: https://gitlab.sgalinski.de/typo3/sg_jobs

TYPO3 version: >8.7

## About
This extension provides job application functionality for a TYPO3 installation.

### Features:
* Creating jobs, including related details like companies and contacts
* Applying for the created jobs
* Applications include file uploads
* Every application is saved conveniently in a CSV format, along with the 
uploaded files
* Sends mail notifications when applications are submitted
* Provides a JobTitleMapper for the TYPO3 9 route enhancers

## Integration
Typoscript files need to be included manually.

```
plugin.tx_sgjobs {
	settings {
		allowedFileExtensions - allowed file extensions for the uploads (default pdf)
		allowedMimeTypes - allowed mime types for the uploads (default application/pdf)
	}
}
```

## Upload file size
By default the maximum file size for an upload is 5MB / 5000kB. You can change this limit in the **constants.ts** configuration file:

	settings {
    		.....
    		# cat=plugin.tx_sgjobs/other; type=string; label=Allowed maximum file size for uploads in kB
    		allowedMaxFileSize = 5000
    	}


## Backend Module
The Backend module is found in the **WEB** section under the name **Job Offers**.

You can create a new job offer by clicking on the **New Job Offer** button.

## Setting the contact email
When a user applies to a job offer an email will be send. The adress of this email comes either from the
**contact person** assigned to the job, ot if no contact person is set, the mail address is chosen from the selected 
location.

Simply supply the uid of the contact record and every job without a contact person will use the desired contact.

## Setting the record page id for the Joblist plugin
You need to set the id of the page (or sys folder) where you store all your job offers, contacts and locations.
To do this you can select the page/folder as Record Storage Page in the plugin settings.

## Job form page 
When inserting the joblist plugin on a page, make sure to select the page which 
contains the application form from 
Plugin -> Plugin Options -> Page containing the application form

## Automated Email Messages

The extension uses **sg_mail** to configure email templates.

##.htaccess

The folder which contains the applications folder should be blocked from outside 
access from the .htaccess file. Example:

```
RedirectMatch 403 ^/fileadmin/JobApplication/.*$
```

## Implement job title mapping in TYPO3 9

To enable the job title mapping in TYPO3 9, you need to add this routeEnhancer configuration to your config.yaml.
```
routeEnhancers:
	SgJobApplication:
        type: Extbase
        extension: SgJobs
        plugin: JobApplication
        routes:
            -   routePath: '/job/applyform/{job_title}'
                _controller: 'Joblist::applyForm'
                _arguments:
                    job_title: jobId
            -   routePath: '/job/apply'
                _controller: 'Joblist::apply'
        defaultController: 'Joblist::applyForm'
        aspects:
            job_title:
                type: JobTitleMapper
    SgJobList:
        type: Extbase
        extension: SgJobs
        plugin: Joblist
        routes:
            -   routePath: '/job/{job_title}'
                _controller: 'Joblist::index'
                _arguments:
                    job_title: jobId
        defaultController: 'Joblist::index'
        aspects:
            job_title:
                type: JobTitleMapper
```

This configuration will use the JobTitleMapper to map the job title to the jobs is.
The routePath represents the speaking URL part where {job_title} is the placeholder for the job title.
The JobTitleMapper is assigned to the job_title placeholder via aspects and will take care of the encoding and decoding
of the job title and the according job id.

## Migration from version 1 to version 2

If you update from sg_job version 1, you need to execute the Upgrade Wizard, that migrates the old area field.
To do so, please visit the Install Tool and click on Upgrade Wizards. Check the Job Upgrade Wizard and execute it.
This Wizard will migrate your area data into department records.

Also please be aware of changes to the Fluid template regarding the area -> department migration and change the area
occurences of variables in the template to department records accordingly.

This version also introduces correct exclude field configurations for the tables, so check your backend user 
and backend usergroup permissions and adjust them accordingly.
